This function will generate n random points from a Bernoulli
distribution with a user provided, .prob, and number of random simulations
to be produced. The function returns a tibble with the simulation number
column the x column which corresponds to the n randomly generated points,
the d_, p_ and q_ data points as well.
The data is returned un-grouped.
The columns that are output are:
sim_number The current simulation number.
x The current value of n for the current simulation.
y The randomly generated data point.
dx The x value from the stats::density() function.
dy The y value from the stats::density() function.
p The values from the resulting p_ function of the distribution family.
q The values from the resulting q_ function of the distribution family.
tidy_bernoulli(.n = 50, .prob = 0.1, .num_sims = 1, .return_tibble = TRUE)A tibble of randomly generated data.
The number of randomly generated points you want.
The probability of success/failure.
The number of randomly generated simulations you want.
A logical value indicating whether to return the result as a tibble. Default is TRUE.
Steven P. Sanderson II, MPH
This function uses the rbinom(), and its underlying
p, d, and q functions. The Bernoulli distribution is a special case
of the Binomial distribution with size = 1 hence this is why the binom
functions are used and set to size = 1.
https://en.wikipedia.org/wiki/Bernoulli_distribution
Other Discrete Distribution:
tidy_binomial(),
tidy_geometric(),
tidy_hypergeometric(),
tidy_negative_binomial(),
tidy_poisson(),
tidy_zero_truncated_binomial(),
tidy_zero_truncated_negative_binomial(),
tidy_zero_truncated_poisson()
Other Bernoulli:
util_bernoulli_param_estimate(),
util_bernoulli_stats_tbl()