This function will generate n random points from a Zero Truncated
Poisson distribution with a user provided, .lambda, and number of
random simulations to be produced. The function returns a tibble with the
simulation number column the x column which corresponds to the n randomly
generated points, the d_, p_ and q_ data points as well.
The data is returned un-grouped.
The columns that are output are:
sim_number The current simulation number.
x The current value of n for the current simulation.
y The randomly generated data point.
dx The x value from the stats::density() function.
dy The y value from the stats::density() function.
p The values from the resulting p_ function of the distribution family.
q The values from the resulting q_ function of the distribution family.
tidy_zero_truncated_poisson(
.n = 50,
.lambda = 1,
.num_sims = 1,
.return_tibble = TRUE
)A tibble of randomly generated data.
The number of randomly generated points you want.
A vector of non-negative means.
The number of randomly generated simulations you want.
A logical value indicating whether to return the result as a tibble. Default is TRUE.
Steven P. Sanderson II, MPH
This function uses the underlying actuar::rztpois(), and its underlying
p, d, and q functions. For more information please see actuar::rztpois()
https://openacttexts.github.io/Loss-Data-Analytics/ChapSummaryDistributions.html
Other Poisson:
tidy_poisson(),
util_poisson_param_estimate(),
util_poisson_stats_tbl(),
util_zero_truncated_poisson_param_estimate(),
util_zero_truncated_poisson_stats_tbl()
Other Zero Truncated Distribution:
tidy_zero_truncated_binomial(),
tidy_zero_truncated_geometric(),
util_zero_truncated_binomial_param_estimate()
Other Discrete Distribution:
tidy_bernoulli(),
tidy_binomial(),
tidy_hypergeometric(),
tidy_negative_binomial(),
tidy_poisson(),
tidy_zero_truncated_binomial(),
tidy_zero_truncated_negative_binomial()